@@ -1,5 +1,5 @@
 # This file is part of CairoSVG
-# Copyright © 2010-2015 Kozea
+# Copyright © 2010-2018 Kozea
 #
 # This library is free software: you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -67,7 +67,6 @@ def point_following_path(path, width):
 
 def text(surface, node):
     """Draw a text ``node``."""
-    font_size = size(surface, node.get('font-size', '12pt'))
     font_family = (
         (node.get('font-family') or 'sans-serif').split(',')[0].strip('"\' '))
     font_style = getattr(
@@ -77,7 +76,7 @@ def text(surface, node):
         cairo, ('font_weight_{}'.format(node.get('font-weight')).upper()),
         cairo.FONT_WEIGHT_NORMAL)
     surface.context.select_font_face(font_family, font_style, font_weight)
-    surface.context.set_font_size(font_size)
+    surface.context.set_font_size(surface.font_size)
     ascent, descent, _, max_x_advance, max_y_advance = (
         surface.context.font_extents())
 
@@ -111,13 +110,14 @@ def text(surface, node):
     last_r = rotate[-1]
     letters_positions = zip_letters(x, y, dx, dy, rotate, node.text)
 
+    x_align = 0
+    y_align = 0
+
     text_anchor = node.get('text-anchor')
     if text_anchor == 'middle':
         x_align = width / 2. + x_bearing
     elif text_anchor == 'end':
         x_align = width + x_bearing
-    else:
-        x_align = 0
 
     # TODO: This is a hack. The rest of the baseline alignment tags of the SVG
     # 1.1 spec (section 10.9.2) are not supported. We only try to align things
@@ -150,8 +150,6 @@ def text(surface, node):
               alignment_baseline == 'bottom' or
               alignment_baseline == 'text-bottom'):
             y_align = -descent
-        else:
-            y_align = 0
 
     bounding_box = EMPTY_BOUNDING_BOX
     if text_path:
@@ -162,7 +160,9 @@ def text(surface, node):
         surface.context.new_path()
         length = path_length(cairo_path) + x_bearing
         start_offset = size(surface, node.get('startOffset', 0), length)
-        surface.text_path_width += start_offset - x_align
+        if node.tag == 'textPath':
+            surface.text_path_width += start_offset
+        surface.text_path_width -= x_align
         bounding_box = extend_bounding_box(bounding_box, ((start_offset, 0),))
 
     if node.text:
