@@ -1,5 +1,5 @@
 # This file is part of CairoSVG
-# Copyright © 2010-2015 Kozea
+# Copyright © 2010-2018 Kozea
 #
 # This library is free software: you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -21,16 +21,69 @@ Utils dealing with URLs.
 
 import os.path
 import re
+from pathlib import Path
 from urllib.parse import urljoin, urlparse
 from urllib.request import Request, urlopen
 
-from . import __version__
+from . import VERSION
 
-HTTP_HEADERS = {'User-Agent': 'CairoSVG {}'.format(__version__)}
+HTTP_HEADERS = {'User-Agent': 'CairoSVG {}'.format(VERSION)}
 
 URL = re.compile(r'url\((.+)\)')
 
 
+def normalize_url(url):
+    """Normalize ``url`` for underlying NT/Unix operating systems.
+
+    The input ``url`` may look like the following:
+
+        - C:\Directory\zzz.svg
+        - file://C:\Directory\zzz.svg
+        - zzz.svg
+
+    The output ``url`` on NT systems would look like below:
+
+        - file:///C:/Directory/zzz.svg
+
+    """
+    if url and os.name == 'nt':
+        # Match input ``url`` like the following:
+        #   - C:\Directory\zzz.svg
+        #   - Blah.svg
+        if 'file:' not in url:
+            url = os.path.abspath(url)
+            url = Path(url).resolve().as_uri()
+
+        # Match input ``url`` like the following:
+        #   - file://C:\Directory\zzz.svg
+        elif re.match(
+                '^file://[a-z]:', url,
+                re.IGNORECASE | re.MULTILINE | re.DOTALL):
+            url = url.replace('//', '///')
+            url = url.replace('\\', '/')
+
+    return url
+
+
+def nt_compatible_path(path):
+    """Provide compatible NT file paths for ``os.path`` functions
+
+    ``os.path`` expects NT paths with no ``/`` at the beginning. For
+    example, ``/C:/Directory/zzz.svg`` would fail ``os.path.isfile()``,
+    ``os.path.isdir()`` etc. where the expected input for `os.path`
+    functions is ``/C:/Directory/zzz.svg``.
+
+    Currently ``nt_compatible_path`` performs some basic checks and
+    eliminates the unwanted ``/`` at the beginning.
+
+    """
+    if os.name == 'nt' and re.match(
+            '^/[a-z]:/', path, re.IGNORECASE | re.MULTILINE | re.DOTALL):
+        return re.sub('^/', '', path, re.IGNORECASE | re.MULTILINE | re.DOTALL)
+    else:
+        return path
+
+
 def fetch(url, resource_type):
     """Fetch the content of ``url``.
 
@@ -57,20 +110,22 @@ def parse_url(url, base=None):
             parsed_url = urlparse(url)
             if parsed_base.scheme in ('', 'file'):
                 if parsed_url.scheme in ('', 'file'):
+                    parsed_base_path = nt_compatible_path(parsed_base.path)
+                    parsed_url_path = nt_compatible_path(parsed_url.path)
                     # We are sure that `url` and `base` are both file-like URLs
-                    if os.path.isfile(parsed_base.path):
-                        if parsed_url.path:
+                    if os.path.isfile(parsed_base_path):
+                        if parsed_url_path:
                             # Take the "folder" part of `base`, as
                             # `os.path.join` doesn't strip the file name
                             url = os.path.join(
-                                os.path.dirname(parsed_base.path),
-                                parsed_url.path)
+                                os.path.dirname(parsed_base_path),
+                                parsed_url_path)
                         else:
-                            url = parsed_base.path
-                    elif os.path.isdir(parsed_base.path):
-                        if parsed_url.path:
+                            url = parsed_base_path
+                    elif os.path.isdir(parsed_base_path):
+                        if parsed_url_path:
                             url = os.path.join(
-                                parsed_base.path, parsed_url.path)
+                                parsed_base_path, parsed_url_path)
                         else:
                             url = ''
                     else:
@@ -80,7 +135,7 @@ def parse_url(url, base=None):
             elif parsed_url.scheme in ('', parsed_base.scheme):
                 # `urljoin` automatically uses the "folder" part of `base`
                 url = urljoin(base, url)
-        url = url.strip('\'"')
+        url = normalize_url(url.strip('\'"'))
     return urlparse(url or '')
 
 
@@ -93,4 +148,6 @@ def read_url(url, url_fetcher, resource_type):
         url = url.geturl()
     else:
         url = 'file://{}'.format(os.path.abspath(url.geturl()))
+        url = normalize_url(url)
+
     return url_fetcher(url, resource_type)
